==> fusionforge_5.1.1.orig.tar.gz: fusionforge-5.1.1/plugins/wiki/www/locale/nl/LC_MESSAGES/phpwiki.php <==
<?php

$locale["%4d  %s\n"] = "%4d  %s\n";
$locale["%s: %s"] = "%s: %s";
$locale["(Copy your changes to the clipboard. You can try editing a different page or save your text in a text editor.)"] = "Kopier je veranderingen naar het klipbord of een andere tijdelijke plaats (bijv. een tekst editor).";
$locale["(diff)"] = "(diff)";
$locale["- saved to database as version %d"] = "- bewaard in de data base als versie %d";
$locale["Administration"] = "Beheer";
$locale["An unnamed PhpWiki"] = "Naamloos PhpWiki";
$locale["Back Links"] = "Terug Links";
$locale["BackLinks"] = "TerugLinks";
$locale["Cancel"] = "Annuleer";
$locale["Changes"] = "Veranderingen";
$locale["Complete."] = "Klaar.";
$locale["Couldn't connect to %s"] = "Kan verbinding naar data base %s niet tot stand brengen, geef op.";
$locale["Describe %s here."] = "Beschrijf %s hier.";
$locale["Diff"] = "Diff";
$locale["Diff: %s"] = "Diff van: %s";
$locale["Edit"] = "Verander";
$locale["Edit %s"] = "Verander %s";
$locale["Edit: %s"] = "Verander: %s";
$locale["EditText"] = "VeranderTekst";
$locale["Edited by: %s"] = "Verander von: %s";
$locale["Fatal PhpWiki Error"] = "PhpWiki Fatale Fout";
$locale["FindPage"] = "ZoekPagina";
$locale["Full text search results for '%s'"] = "Volledige tekst zoek resultaten naar '%s'";
$locale["FullTextSearch"] = "VolledigeTekstZoek";
$locale["H"] = "H";
$locale["Height"] = "Hoogte";
$locale["Help"] = "Help";
$locale["Help/GoodStyle"] = "Help/GoedeStijl";
$locale["Help/OldTextFormattingRules"] = "Help/OudTekstFormatteringsRegels";
$locale["Help/TextFormattingRules"] = "Help/TekstFormatteringsRegels";
$locale["Help/WabiSabi"] = "Help/WabiSabi";
$locale["Help/WikiWikiWeb"] = "Help/WikiWikiWeb";
$locale["History"] = "Geschiedenis";
$locale["Hits"] = "Teller";
$locale["Hits:"] = "Teller:";
$locale["Home"] = "Thuis";
$locale["Home Page"] = "Thuis Pagina";
$locale["Home page"] = "Thuis Pagina";
$locale["HomePage"] = "ThuisPagina";
$locale["Last Author"] = "Vorige Auteur";
$locale["Last Modified"] = "meest recente verandering";
$locale["Last edited %s"] = "Meest recente verandering %s";
$locale["Last edited on %s"] = "Meest recente verandering op %s";
$locale["LdapSearch"] = "LdapZoek";
$locale["Links"] = "Links";
$locale["LiveSearch"] = "LiveZoek";
$locale["Loading up virgin wiki"] = "Laden van maagdelijke wiki";
$locale["Lock Page"] = "Open Pagina";
$locale["Locked"] = "Låst";
$locale["MIME file %s"] = "MIME bestand %s";
$locale["MostPopular"] = "MeestBezocht";
$locale["My Changes"] = "Mijn Veranderingen";
$locale["MyRecentChanges"] = "MijnRecenteVeranderingen";
$locale["New page"] = "Nieuw pagina";
$locale["Newer page:"] = "Nieuw pagina:";
$locale["Next"] = "Volgende";
$locale["None"] = "Geen";
$locale["Page"] = "Pagina";
$locale["Page Locked"] = "Sidan är Låst";
$locale["Page Name"] = "Pagina Naam";
$locale["PageHistory"] = "PaginaGeschiedenis";
$locale["PhpWikiAdministration"] = "PhpWikiBeheer";
$locale["PhpWikiAdministration/Chmod"] = "PhpWikiBeheer/Chmod";
$locale["PhpWikiAdministration/Markup"] = "PhpWikiBeheer/Markup";
$locale["PhpWikiAdministration/Replace"] = "PhpWikiBeheer/Vervangt";
$locale["PhpWikiDocumentation"] = "PhpWikiDocumentatie";
$locale["Preview"] = "Voorvertonig";
$locale["Previous"] = "Vorige";
$locale["Previous Author"] = "Vorige Auteur";
$locale["Printer"] = "Drukker";
$locale["Recent Changes"] = "Recente Veranderingen";
$locale["Recent changes"] = "Recente Veranderingen";
$locale["RecentChanges"] = "RecenteVeranderingen";
$locale["RecentVisitors"] = "RecenteBezoekers";
$locale["References"] = "Referenties";
$locale["ReleaseNotes"] = "UitgaveNoten";
$locale["Remove Page"] = "Verwijder Pagina";
$locale["Removed page '%s' successfully."] = "Pagina '%s' verwijderd.";
$locale["Return to %s"] = "Terug naar %s";
$locale["SandBox"] = "ZandBak";
$locale["Save"] = "Bewaar";
$locale["Saved: %s"] = "Bewaard: %s";
$locale["Search"] = "Zoek";
$locale["Search & Replace"] = "Zoek & Vervangt";
$locale["See %s"] = "Zie %s";
$locale["See %s tips for editing."] = "%s tips for veranderen.";
$locale["Serialized file %s"] = "Geserialiseerd bestand %s";
$locale["Skipping"] = "Overgeslagen";
$locale["Sorry for the inconvenience."] = "Excuses voor het ongemak.";
$locale["TextFormattingRules"] = "TekstFormatteringsRegels";
$locale["Thank you for editing %s."] = "Bedankt voor het veranderen van %s.";
$locale["The %d most popular pages of this wiki:"] = "De %d meestbezochte pagina's van deze Wiki:";
$locale["The %d most recent %s are listed below."] = "De %d meest recent %s staan hieronder.";
$locale["This page has been locked by the administrator so your changes can not be saved."] = "Deze pagina is afgesloten door de beheerder en je veranderingen kan niet bewaar worden.";
$locale["Title Search"] = "Titel Zoek";
$locale["Title search results for '%s'"] = "Titel zoek resultaten naar '%s'";
$locale["TitleSearch"] = "TitelZoek";
$locale["Unlock Page"] = "Sluit Pagina Af";
$locale["Update Preferences"] = "Zet Voorkeuren";
$locale["UserPreferences"] = "GebruikersVoorkeuren";
$locale["Version"] = "Versie";
$locale["Version %d"] = "Versie %d";
$locale["Version %s, saved on %s"] = "Versie %s, bewarrd op %s";
$locale["Versions are identical"] = "Versies zijn identiek";
$locale["View Source"] = "Bron Tekst";
$locale["View Source: %s"] = "Bron tekst: %s";
$locale["W"] = "B";
$locale["Width"] = "Breedte";
$locale["Wiki Admin"] = "PhpWiki Beheer";
$locale["You are about to remove '%s'!"] = "Je staat te verwijderen '%s' op het punt!";
$locale["You must specify a directory to dump to"] = "Je moet een directory specificeren om in te storten";
$locale["Your careful attention to detail is much appreciated."] = "Je zorgvuldige aandacht voor detail wordt erg gewaardeerd.";
$locale["Your home page has not been created yet so your preferences cannot not be saved."] = "Deze pagina is afgesloten door de beheerder en je veranderingen kan niet bewaar worden.";
$locale["[%d] See [%s]"] = "[%d] Zie [%s]";
$locale["by %s"] = "door %s";
$locale["current version"] = "huidige versie";
$locale["diff"] = "diff";
$locale["from %s"] = "van %s";
$locale["locked"] = "låst";
$locale["plain file %s"] = "plat bestand %s";
$locale["saved as %s"] = "bewaard als %s";
$locale["version %d"] = "versie %d";
$locale["version %s"] = "versie %s";
$locale["version <em>%s</em>"] =
   "versie <em>%s</em>";

?>

==> fusionforge_5.2~rc1+1.tar.gz: fusionforge-5.2~rc1+1/plugins/wiki/www/locale/nl/LC_MESSAGES/phpwiki.php <==
<?php

$locale[" Skipped"] = "Overgeslagen";
$locale[" is identical."] = " zijn identiek";
$locale[" to "] = " naar ";
$locale["%4d  %s\n"] = "%4d  %s\n";
$locale["%s: %s"] = "%s: %s";
$locale["(Copy your changes to the clipboard. You can try editing a different page or save your text in a text editor.)"] = "Kopier je veranderingen naar het klipbord of een andere tijdelijke plaats (bijv. een tekst editor).";
$locale["(diff)"] = "(diff)";
$locale["- saved to database as version %d"] = "- bewaard in de data base als versie %d";
$locale["Administration"] = "Beheer";
$locale["An unnamed PhpWiki"] = "Naamloos PhpWiki";
$locale["Back"] = "Terug";
$locale["Back Links"] = "Terug Links";
$locale["BackLinks"] = "TerugLinks";
$locale["Cancel"] = "Annuleer";
$locale["Changes"] = "Veranderingen";
$locale["Complete."] = "Klaar.";
$locale["Couldn't connect to %s"] = "Kan verbinding naar data base %s niet tot stand brengen, geef op.";
$locale["Describe %s here."] = "Beschrijf %s hier.";
$locale["Diff"] = "Diff";
$locale["Diff: %s"] = "Diff van: %s";
$locale["Edit"] = "Verander";
$locale["Edit %s"] = "Verander %s";
$locale["Edit: %s"] = "Verander: %s";
$locale["EditText"] = "VeranderTekst";
$locale["Edited by: %s"] = "Verander von: %s";
$locale["Fatal PhpWiki Error"] = "PhpWiki Fatale Fout";
$locale["Find page"] = "Zoek Pagina";
$locale["FindPage"] = "ZoekPagina";
$locale["Full text search results for '%s'"] = "Volledige tekst zoek resultaten naar '%s'";
$locale["FullTextSearch"] = "VolledigeTekstZoek";
$locale["H"] = "H";
$locale["Height"] = "Hoogte";
$locale["Help"] = "Help";
$locale["Help/GoodStyle"] = "Help/GoedeStijl";
$locale["Help/OldTextFormattingRules"] = "Help/OudTekstFormatteringsRegels";
$locale["Help/TextFormattingRules"] = "Help/TekstFormatteringsRegels";
$locale["Help/WabiSabi"] = "Help/WabiSabi";
$locale["Help/WikiWikiWeb"] = "Help/WikiWikiWeb";
$locale["History"] = "Geschiedenis";
$locale["Hits"] = "Teller";
$locale["Home"] = "Thuis";
$locale["Home Page"] = "Thuis Pagina";
$locale["HomePage"] = "ThuisPagina";
$locale["Last Author"] = "Vorige Auteur";
$locale["Last Modified"] = "meest recente verandering";
$locale["Last edited on %s"] = "Meest recente verandering op %s";
$locale["LdapSearch"] = "LdapZoek";
$locale["Links"] = "Links";
$locale["LiveSearch"] = "LiveZoek";
$locale["Loading up virgin wiki"] = "Laden van maagdelijke wiki";
$locale["Lock Page"] = "Open Pagina";
$locale["Locked"] = "Låst";
$locale["MIME file %s"] = "MIME bestand %s";
$locale["MostPopular"] = "MeestBezocht";
$locale["My Changes"] = "Mijn Veranderingen";
$locale["My Preferences"] = "Mijn Voorkeuren";
$locale["MyRecentChanges"] = "MijnRecenteVeranderingen";
$locale["New page"] = "Nieuw pagina";
$locale["Newer page:"] = "Nieuw pagina:";
$locale["Next"] = "Volgende";
$locale["None"] = "Geen";
$locale["Page"] = "Pagina";
$locale["Page Locked"] = "Sidan är Låst";
$locale["Page Name"] = "Pagina Naam";
$locale["Page Version"] = "Pagina Versie";
$locale["PageHistory"] = "PaginaGeschiedenis";
$locale["PhpWikiAdministration"] = "PhpWikiBeheer";
$locale["PhpWikiAdministration/Chmod"] = "PhpWikiBeheer/Chmod";
$locale["PhpWikiAdministration/Markup"] = "PhpWikiBeheer/Markup";
$locale["PhpWikiAdministration/Replace"] = "PhpWikiBeheer/Vervangt";
$locale["PhpWikiDocumentation"] = "PhpWikiDocumentatie";
$locale["Preview"] = "Voorvertonig";
$locale["Previous"] = "Vorige";
$locale["Previous Author"] = "Vorige Auteur";
$locale["Printer"] = "Drukker";
$locale["Purge this page"] = "Verwijder pagina";
$locale["Purged page '%s' successfully."] = "Pagina '%s' verwijderd.";
$locale["Recent Changes"] = "Recente Veranderingen";
$locale["Recent changes"] = "Recente Veranderingen";
$locale["RecentChanges"] = "RecenteVeranderingen";
$locale["RecentVisitors"] = "RecenteBezoekers";
$locale["References"] = "Referenties";
$locale["ReleaseNotes"] = "UitgaveNoten";
$locale["Remove Page"] = "Verwijder Pagina";
$locale["Removed page '%s' successfully."] = "Pagina '%s' verwijderd.";
$locale["Replace"] = "Vervangt";
$locale["Return to %s"] = "Terug naar %s";
$locale["SandBox"] = "ZandBak";
$locale["Save"] = "Bewaar";
$locale["Saved: %s"] = "Bewaard: %s";
$locale["Search"] = "Zoek";
$locale["Search & Replace"] = "Zoek & Vervangt";
$locale["Search for"] = "Zoek";
$locale["Search:"] = "Zoek:";
$locale["SearchReplace"] = "ZoekVervangt";
$locale["See %s"] = "Zie %s";
$locale["See %s tips for editing."] = "%s tips for veranderen.";
$locale["Serialized file %s"] = "Geserialiseerd bestand %s";
$locale["Sidebar"] = "Zoek";
$locale["Skipping"] = "Overgeslagen";
$locale["Sorry for the inconvenience."] = "Excuses voor het ongemak.";
$locale["Template Name"] = "Template Naam";
$locale["TextFormattingRules"] = "TekstFormatteringsRegels";
$locale["Thank you for editing %s."] = "Bedankt voor het veranderen van %s.";
$locale["The %d most popular pages of this wiki:"] = "De %d meestbezochte pagina's van deze Wiki:";
$locale["The %d most recent %s are listed below."] = "De %d meest recent %s staan hieronder.";
$locale["This page has been locked and cannot be edited."] = "Deze pagina is afgesloten en kan niet veranderd worden.";
$locale["This page has been locked by the administrator so your changes can not be saved."] = "Deze pagina is afgesloten door de beheerder en je veranderingen kan niet bewaar worden.";
$locale["Title 1"] = "Titel 1";
$locale["Title 2"] = "Titel 2";
$locale["Title 3"] = "Titel 3";
$locale["Title Search"] = "Titel Zoek";
$locale["Title search results for '%s'"] = "Titel zoek resultaten naar '%s'";
$locale["Title search results for '%s' (%d total)"] = "Titel zoek resultaten naar '%s' (%d total)";
$locale["TitleSearch"] = "TitelZoek";
$locale["Unlock Page"] = "Sluit Pagina Af";
$locale["Update Preferences"] = "Zet Voorkeuren";
$locale["UserPreferences"] = "GebruikersVoorkeuren";
$locale["Version"] = "Versie";
$locale["Version "] = "Versie ";
$locale["Version %d"] = "Versie %d";
$locale["Version %s, saved on %s"] = "Versie %s, bewarrd op %s";
$locale["Versions are identical"] = "Versies zijn identiek";
$locale["View Source"] = "Bron Tekst";
$locale["View Source: %s"] = "Bron tekst: %s";
$locale["W"] = "B";
$locale["Wanted Pages in this wiki (%d total):"] = "De %d meestbezochte pagina's van deze Wiki:";
$locale["Width"] = "Breedte";
$locale["Wiki Admin"] = "PhpWiki Beheer";
$locale["You are about to purge '%s'!"] = "Je staat te verwijderen '%s'!";
$locale["You are about to remove '%s'!"] = "Je staat te verwijderen '%s' op het punt!";
$locale["You must specify a directory to dump to"] = "Je moet een directory specificeren om in te storten";
$locale["Your careful attention to detail is much appreciated."] = "Je zorgvuldige aandacht voor detail wordt erg gewaardeerd.";
$locale["Your home page has not been created yet so your preferences cannot not be saved."] = "Deze pagina is afgesloten door de beheerder en je veranderingen kan niet bewaar worden.";
$locale["Your home page is locked so your preferences cannot not be saved."] = "Deze pagina is afgesloten en je veranderingen kan niet bewaar worden.";
$locale["[%d] See [%s]"] = "[%d] Zie [%s]";
$locale["by %s"] = "door %s";
$locale["current version"] = "huidige versie";
$locale["diff"] = "diff";
$locale["from %s"] = "van %s";
$locale["from '%s'"] = "van %s";
$locale["locked"] = "låst";
$locale["new pages"] = "nieuw pagina";
$locale["plain file %s"] = "plat bestand %s";
$locale["saved as %s"] = "bewaard als %s";
$locale["to '%s'."] = "naar '%s'.";
$locale["version %d"] = "versie %d";
$locale["version %s"] = "versie %s";
$locale["version <em>%s</em>"] =
   "versie <em>%s</em>";

?>
